@@ -3,7 +3,6 @@ import inspect
 import json
 import logging
 
-import aiohttp.client_exceptions
 import botocore.awsrequest
 from botocore.exceptions import (
     InvalidIMDSEndpointError,
@@ -12,6 +11,7 @@ from botocore.exceptions import (
 from botocore.utils import (
     DEFAULT_METADATA_SERVICE_TIMEOUT,
     METADATA_BASE_URL,
+    RETRYABLE_HTTP_ERRORS,
     BadIMDSRequestError,
     ClientError,
     ContainerMetadataFetcher,
@@ -31,10 +31,6 @@ import aiobotocore.httpsession
 from aiobotocore._helpers import asynccontextmanager
 
 logger = logging.getLogger(__name__)
-RETRYABLE_HTTP_ERRORS = (
-    aiohttp.client_exceptions.ClientError,
-    asyncio.TimeoutError,
-)
 
 
 class _RefCountedSession(aiobotocore.httpsession.AIOHTTPSession):
